# Beersmith Direct

We use Beersmith to design our beer recipes. The application interface is nice for a user, but there is no API for direct access. This package reads the recipe files and saves them into a MongoDB database.

## Getting Started

These instructions will get you a copy of the project up and running on your local machine for development and testing purposes.

### Prerequisites

This package supports the following version of Python:

- Python 3.9 or later

### Installing

Install the latest package using pip. (We prefer pipenv.)

```
$ pip install beersmith-direct
```

End with an example of getting some data out of the system or using it for a little demo

## Running the tests

Explain how to run the automated tests for this system

```
$ python -m pytest
```

## Usage

TODO

## Authors

- **Jason Romano** - [Aracnid](https://github.com/aracnid)

See also the list of [contributors](https://github.com/lakeannebrewhouse/beersmith-direct/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details
